@@ -1,7 +1,7 @@
 package App::Wubot::Check;
 use Moose;
 
-our $VERSION = '0.3.5'; # VERSION
+our $VERSION = '0.3.6'; # VERSION
 
 use Benchmark;
 use YAML;
@@ -18,7 +18,7 @@ App::Wubot::Check - perform checks for an instance of a monitor
 
 =head1 VERSION
 
-version 0.3.5
+version 0.3.6
 
 =head1 SYNOPSIS
 
@@ -267,11 +267,6 @@ sub _react_results {
         return;
     }
 
-    # push any configured 'tags' along with the message
-    if ( $config && $config->{tags} ) {
-        $react->{tags} = $config->{tags};
-    }
-
     # use our class name for the 'plugin' field
     unless ( $react->{plugin} ) {
         $react->{plugin}     = $self->{class};
